@@ -29,6 +29,7 @@
                  (apheleia-formatters-indent
                   "--tab" "--indent-size" 'sh-basic-offset)
                  "-"))
+    (bibtex . apheleia-reformat-bibtex-buffer)
     (black . ("black"
               (when (apheleia-formatters-extension-p "pyi") "--pyi")
               (apheleia-formatters-fill-column "--line-length")
@@ -111,6 +112,7 @@
                     "--enable-outside-detected-project"))
     (ocp-indent . ("ocp-indent"))
     (ormolu . ("ormolu" "--stdin-input-file" filepath))
+    (oxfmt . ("apheleia-npx" "oxfmt" inplace))
     (perltidy . ("perltidy" "--quiet" "--standard-error-output"
                  (apheleia-formatters-indent "-t" "-i")
                  (apheleia-formatters-fill-column "-l")))
@@ -180,7 +182,8 @@
      . ("python3" "-m" "json.tool"
         (apheleia-formatters-indent "--tab" "--indent")))
     (rubocop . ("rubocop" "--stdin" filepath "-a"
-                "--stderr" "--format" "quiet" "--fail-level" "fatal"))
+                "--stderr" "--format" "quiet" "--fail-level" "fatal"
+                "--force-exclusion"))
     (ruby-standard . ("standardrb" "--stdin" filepath "--fix" "--stderr"
                       "--format" "quiet" "--fail-level" "fatal"))
     (ruby-syntax-tree . ("apheleia-from-project-root"
@@ -205,13 +208,13 @@
                       (sh "posix")
                       (t "bash"))
               (when apheleia-formatters-respect-indent-level
-                (list
-                 "-i" (number-to-string
-                       (cond
-                        (indent-tabs-mode 0)
-                        ((boundp 'sh-basic-offset)
-                         sh-basic-offset)
-                        (t 4)))))
+                (format
+                 "--indent=%d"
+                 (cond
+                  (indent-tabs-mode 0)
+                  ((boundp 'sh-basic-offset)
+                   sh-basic-offset)
+                  (t 4))))
               "-"))
     (rufo . ("rufo" "--filename" filepath "--simple-exit"))
     (stylua . ("stylua" "-"))
@@ -235,7 +238,7 @@
     (yq-xml . ("yq" "--prettyPrint" "--no-colors"
                "--input-format" "xml" "--output-format" "xml"
                (apheleia-formatters-indent nil "--indent")))
-    (yq-yaml . ("yq" "--prettyPrint" "--no-colors" "--no-doc"
+    (yq-yaml . ("yq" "--prettyPrint" "--no-colors"
                 "--input-format" "yaml" "--output-format" "yaml"
                 (apheleia-formatters-indent nil "--indent")))
     (zig-fmt . ("zig" "fmt" "--stdin")))
@@ -318,6 +321,7 @@ rather than using this system."
     (bash-ts-mode . shfmt)
     (bazel-mode . buildifier)
     (beancount-mode . bean-format)
+    (bibtex-mode . bibtex)
     (c++-ts-mode . clang-format)
     (caddyfile-mode . caddyfmt)
     (cc-mode . clang-format)
@@ -463,6 +467,23 @@ in the buffer."
          'mhtml-submode)
     #'mhtml-mode))
 
+;; Expected exit code and stderr output for script when real
+;; formatter is not available
+(defvar apheleia-script--formatter-not-available
+  '(:exit-code 100 :stderr "formatter_not_available"))
+
+(defun apheleia-script--formatter-not-available-p (ctx stderr)
+  "Check if script reports that no formatter has been found.
+CTX is a formatter process context.
+STDERR is the stderr output of process."
+  (and (eq (apheleia-formatter--exit-status ctx)
+           (plist-get apheleia-script--formatter-not-available :exit-code))
+       (string= stderr
+                (concat
+                 (apheleia-formatter--arg1 ctx) ":"
+                 (plist-get apheleia-script--formatter-not-available
+                            :stderr)))))
+
 ;;;###autoload
 (defcustom apheleia-mode-predicates '(apheleia-mhtml-mode-predicate)
   "List of predicates that check for sneaky major modes.
@@ -743,9 +764,14 @@ its exit status is 0."
                          proc-exit-status)
                    (let ((exit-ok (and
                                    (not proc-interrupted)
-                                   (funcall
-                                    (or exit-status #'zerop)
-                                    (apheleia-formatter--exit-status ctx)))))
+                                   (or
+                                    (funcall
+                                     (or exit-status #'zerop)
+                                     (apheleia-formatter--exit-status ctx))
+                                    (apheleia-script--formatter-not-available-p
+                                     ctx
+                                     (with-current-buffer stderr
+                                       (string-trim (buffer-string))))))))
                      ;; Append standard-error from current formatter
                      ;; to log buffer when
                      ;; `apheleia-log-only-errors' is nil or the
@@ -1223,6 +1249,20 @@ For more implementation detail, see
       (indent-region (point-min) (point-max)))
     (funcall callback)))
 
+(cl-defun apheleia-reformat-bibtex-buffer
+    (&key buffer scratch callback &allow-other-keys)
+  "Format a Bibtex BUFFER.
+Use SCRATCH as a temporary buffer and CALLBACK to apply the
+transformation.
+
+For more implementation detail, see
+`apheleia--run-formatter-function'."
+  (with-current-buffer scratch
+    (funcall (with-current-buffer buffer major-mode))
+    (when (fboundp 'bibtex-reformat)
+      (bibtex-reformat))
+    (funcall callback)))
+
 (cl-defun apheleia--run-formatters
     (formatters buffer remote callback &optional stdin)
   "Run one or more code formatters on the current buffer.
